==> opencl-clhpp-2.0.12-1-any.pkg.tar.xz: usr/share/doc/opencl-clhpp/classcl_1_1_kernel.js <==
var classcl_1_1_kernel =
[
    [ "Kernel", "classcl_1_1_kernel.html#a351422a7e7125812c23610628b0f9de7", null ],
    [ "Kernel", "classcl_1_1_kernel.html#a69b2fc97f80d90a23927a74395d09ec9", null ],
    [ "Kernel", "classcl_1_1_kernel.html#a0c71f37cb53fbe492847fbb2dff2bfed", null ],
    [ "Kernel", "classcl_1_1_kernel.html#a93b516f37993297101dd9d30a4572b23", null ],
    [ "Kernel", "classcl_1_1_kernel.html#a0869347f24520f2d59222f74297c5fe5", null ],
    [ "clone", "classcl_1_1_kernel.html#aec57511d2e4ef1080c27918f79bcb917", null ],
    [ "enableFineGrainedSystemSVM", "classcl_1_1_kernel.html#aed996666686cddb41d660839e709fcd0", null ],
    [ "getArgInfo", "classcl_1_1_kernel.html#aa389b7c8babc945491aad0969bbea3f9", null ],
    [ "getArgInfo", "classcl_1_1_kernel.html#af52642f08f20f79de92b7c0f8ea68765", null ],
    [ "getInfo", "classcl_1_1_kernel.html#aad79793dee31368728dc5faaba31b4fe", null ],
    [ "getInfo", "classcl_1_1_kernel.html#a32b57f5ba1c9fb5d3fe1c8f5c8f067f9", null ],
    [ "getSubGroupInfo", "classcl_1_1_kernel.html#a6b28ded6ef25514adb7450868373ee10", null ],
    [ "getSubGroupInfo", "classcl_1_1_kernel.html#ad59bdc88fe5c881ecb27d9bb212de176", null ],
    [ "getWorkGroupInfo", "classcl_1_1_kernel.html#a48e36ac7c4eace006164e6b7c67c2006", null ],
    [ "getWorkGroupInfo", "classcl_1_1_kernel.html#ae4e8cba9366c1198454766e6b392ed1d", null ],
    [ "operator=", "classcl_1_1_kernel.html#a242f26c280c867f531cc30c953e6d4b9", null ],
    [ "operator=", "classcl_1_1_kernel.html#a73577d4ec1662b6939f8adbfff1f2d81", null ],
    [ "operator=", "classcl_1_1_kernel.html#a8e123d85cd5185946741057048cba828", null ],
    [ "setArg", "classcl_1_1_kernel.html#a3ec081fb9656b0780d808563256dfeff", null ],
    [ "setArg", "classcl_1_1_kernel.html#a9516e70e10909526dfb01f6cfe8b61bd", null ],
    [ "setArg", "classcl_1_1_kernel.html#aa694b5dfe7413e3a38d1185208ec1ec7", null ],
    [ "setArg", "classcl_1_1_kernel.html#a69cdd780a6b77e3b15c7436c5ab665a3", null ],
    [ "setArg", "classcl_1_1_kernel.html#ae10c336ea5a49bd7199995a6ab4c23de", null ],
    [ "setSVMPointers", "classcl_1_1_kernel.html#abadacb0037f711f3460cf5c44b2d4796", null ],
    [ "setSVMPointers", "classcl_1_1_kernel.html#a4ecc854da95b1d0c12a8072d9efb41df", null ],
    [ "setSVMPointers", "classcl_1_1_kernel.html#a36633bcfea86c512cbb4fd9b20c6087e", null ],
    [ "setSVMPointersHelper", "classcl_1_1_kernel.html#a16d2f73d0e8e1a175bba604ae5e38b2d", null ],
    [ "setSVMPointersHelper", "classcl_1_1_kernel.html#a09bbe9eac712ad45cda4b7363c39aa4b", null ],
    [ "setSVMPointersHelper", "classcl_1_1_kernel.html#ab2f520c71efd82ee7effff41728417dd", null ],
    [ "setSVMPointersHelper", "classcl_1_1_kernel.html#a2814ec9a3596f0486b9c207c04ee0ab6", null ]
];

==> opencl-clhpp-2.0.13-1-any.pkg.tar.xz: usr/share/doc/opencl-clhpp/classcl_1_1_kernel.js <==
var classcl_1_1_kernel =
[
    [ "Kernel", "classcl_1_1_kernel.html#a351422a7e7125812c23610628b0f9de7", null ],
    [ "Kernel", "classcl_1_1_kernel.html#a69b2fc97f80d90a23927a74395d09ec9", null ],
    [ "Kernel", "classcl_1_1_kernel.html#a0c71f37cb53fbe492847fbb2dff2bfed", null ],
    [ "Kernel", "classcl_1_1_kernel.html#a93b516f37993297101dd9d30a4572b23", null ],
    [ "Kernel", "classcl_1_1_kernel.html#a0869347f24520f2d59222f74297c5fe5", null ],
    [ "clone", "classcl_1_1_kernel.html#aec57511d2e4ef1080c27918f79bcb917", null ],
    [ "enableFineGrainedSystemSVM", "classcl_1_1_kernel.html#aed996666686cddb41d660839e709fcd0", null ],
    [ "getArgInfo", "classcl_1_1_kernel.html#aa389b7c8babc945491aad0969bbea3f9", null ],
    [ "getArgInfo", "classcl_1_1_kernel.html#af52642f08f20f79de92b7c0f8ea68765", null ],
    [ "getInfo", "classcl_1_1_kernel.html#aad79793dee31368728dc5faaba31b4fe", null ],
    [ "getInfo", "classcl_1_1_kernel.html#a32b57f5ba1c9fb5d3fe1c8f5c8f067f9", null ],
    [ "getSubGroupInfo", "classcl_1_1_kernel.html#a6b28ded6ef25514adb7450868373ee10", null ],
    [ "getSubGroupInfo", "classcl_1_1_kernel.html#ad59bdc88fe5c881ecb27d9bb212de176", null ],
    [ "getWorkGroupInfo", "classcl_1_1_kernel.html#a48e36ac7c4eace006164e6b7c67c2006", null ],
    [ "getWorkGroupInfo", "classcl_1_1_kernel.html#ae4e8cba9366c1198454766e6b392ed1d", null ],
    [ "operator=", "classcl_1_1_kernel.html#a242f26c280c867f531cc30c953e6d4b9", null ],
    [ "operator=", "classcl_1_1_kernel.html#a73577d4ec1662b6939f8adbfff1f2d81", null ],
    [ "operator=", "classcl_1_1_kernel.html#a8e123d85cd5185946741057048cba828", null ],
    [ "setArg", "classcl_1_1_kernel.html#a3ec081fb9656b0780d808563256dfeff", null ],
    [ "setArg", "classcl_1_1_kernel.html#a9516e70e10909526dfb01f6cfe8b61bd", null ],
    [ "setArg", "classcl_1_1_kernel.html#aa694b5dfe7413e3a38d1185208ec1ec7", null ],
    [ "setArg", "classcl_1_1_kernel.html#a69cdd780a6b77e3b15c7436c5ab665a3", null ],
    [ "setArg", "classcl_1_1_kernel.html#ae10c336ea5a49bd7199995a6ab4c23de", null ],
    [ "setExecInfo", "classcl_1_1_kernel.html#a85ecb20acddef088e63d91af4ca71976", null ],
    [ "setExecInfo", "classcl_1_1_kernel.html#a5839ea6d2e1fe0fc4068d964e1875e7e", null ],
    [ "setSVMPointers", "classcl_1_1_kernel.html#abadacb0037f711f3460cf5c44b2d4796", null ],
    [ "setSVMPointers", "classcl_1_1_kernel.html#a4ecc854da95b1d0c12a8072d9efb41df", null ],
    [ "setSVMPointers", "classcl_1_1_kernel.html#a36633bcfea86c512cbb4fd9b20c6087e", null ],
    [ "setSVMPointersHelper", "classcl_1_1_kernel.html#a16d2f73d0e8e1a175bba604ae5e38b2d", null ],
    [ "setSVMPointersHelper", "classcl_1_1_kernel.html#a09bbe9eac712ad45cda4b7363c39aa4b", null ],
    [ "setSVMPointersHelper", "classcl_1_1_kernel.html#ab2f520c71efd82ee7effff41728417dd", null ],
    [ "setSVMPointersHelper", "classcl_1_1_kernel.html#a2814ec9a3596f0486b9c207c04ee0ab6", null ]
];
